@@ -1,9 +1,9 @@
-# $Id: ODBC.pm 13205 2009-08-19 08:51:11Z mjevans $
+# $Id: ODBC.pm 13947 2010-05-06 14:30:12Z mjevans $
 #
 # Copyright (c) 1994,1995,1996,1998  Tim Bunce
 # portions Copyright (c) 1997-2004  Jeff Urlwin
 # portions Copyright (c) 1997  Thomas K. Wenrich
-# portions Copyright (c) 2007-2009 Martin J. Evans
+# portions Copyright (c) 2007-2010 Martin J. Evans
 #
 # You may distribute under the terms of either the GNU General Public
 # License or the Artistic License, as specified in the Perl README file.
@@ -12,7 +12,7 @@
 
 require 5.006;
 
-$DBD::ODBC::VERSION = '1.23';
+$DBD::ODBC::VERSION = '1.24';
 
 {
     ## no critic (ProhibitMagicNumbers ProhibitExplicitISA)
@@ -25,7 +25,7 @@ $DBD::ODBC::VERSION = '1.23';
 
     @ISA = qw(Exporter DynaLoader);
 
-    # my $Revision = substr(q$Id: ODBC.pm 13205 2009-08-19 08:51:11Z mjevans $, 13,2);
+    # my $Revision = substr(q$Id: ODBC.pm 13947 2010-05-06 14:30:12Z mjevans $, 13,2);
 
     require_version DBI 1.21;
 
@@ -124,7 +124,8 @@ $DBD::ODBC::VERSION = '1.23';
         return {
                 odbc_ignore_named_placeholders => undef, # sth and dbh
                 odbc_default_bind_type => undef, # sth and dbh
-                odbc_force_rebind => undef, # sth & dbh
+                odbc_force_bind_type => undef, # sth and dbh
+                odbc_force_rebind => undef, # sth and dbh
                 odbc_async_exec => undef, # sth and dbh
                 odbc_exec_direct => undef,
                 odbc_SQL_ROWSET_SIZE => undef,
@@ -136,7 +137,8 @@ $DBD::ODBC::VERSION = '1.23';
                 odbc_version => undef,
                 odbc_err_handler => undef,
                 odbc_putdata_start => undef, # sth and dbh
-                odbc_column_display_size => undef # sth and dbh
+                odbc_column_display_size => undef, # sth and dbh
+                odbc_utf8_on => undef # sth and dbh
                };
     }
 
@@ -485,11 +487,13 @@ $DBD::ODBC::VERSION = '1.23';
         return {
                 odbc_ignore_named_placeholders => undef, # sth and dbh
                 odbc_default_bind_type => undef, # sth and dbh
-                odbc_force_rebind => undef, # sth & dbh
+                odbc_force_bind_type => undef, # sth and dbh
+                odbc_force_rebind => undef, # sth and dbh
                 odbc_async_exec => undef, # sth and dbh
                 odbc_query_timeout => undef, # sth and dbh
                 odbc_putdata_start => undef, # sth and dbh
-                odbc_column_display_size => undef # sth and dbh
+                odbc_column_display_size => undef, # sth and dbh
+                odbc_utf8_on => undef # sth and dbh
                };
     }
 
@@ -515,7 +519,7 @@ DBD::ODBC - ODBC Driver for DBI
 
 =head1 VERSION
 
-This documentation refers to DBD::ODBC version 1.22_2.
+This documentation refers to DBD::ODBC version 1.24.
 
 =head1 SYNOPSIS
 
@@ -569,7 +573,7 @@ get a list of checked in changes.
 
 =head2 Contributing
 
-There are six main ways you may help with the development and
+There are seven main ways you may help with the development and
 maintenance of this module:
 
 =over
@@ -633,6 +637,24 @@ of DBD::ODBC and ODBC drivers is a large test suite. I would greatly
 appreciate any test cases and in particular any new test cases for
 databases other than MS SQL Server.
 
+=item Test DBD::ODBC
+
+I have a lot of problems deciding when to move a development release
+to an official release since I get few test reports for development
+releases. What often happens is I call for testers on various lists,
+get a few and then get inundated with requests to do an official
+release. Then I do an official release and loads of rts appear out of
+nowhere and the cycle starts again.
+
+DBD::ODBC by its very nature works with many ODBC Drivers and it is
+impossible for me to have and test them all (this differs from other
+DBDs). If you depend on DBD::ODBC you should be interested in new
+releases and if you send me your email address suggesting you are
+prepared to be part of the DBD::ODBC testing network I will credit you
+in the Changes file and perhaps the main DBD::ODBC file.
+
+
+
 =back
 
 =head2 DBI attribute handling
@@ -688,6 +710,34 @@ internal default.
 B<N.B> If you call the C<bind_param> method with a SQL type this
 overrides everything else above.
 
+=head3 odbc_force_bind_type
+
+This value defaults to 0.
+
+If set to anything other than 0 this will force bound parameters to be
+bound as this type and C<SQLDescribeParam> will not be used.
+
+Older versions of DBD::ODBC assumed the parameter binding type was 12
+(C<SQL_VARCHAR>) and newer versions always attempt to call
+C<SQLDescribeParam> to find the parameter types. If your driver
+supports C<SQLDescribeParam> and it succeeds it may still fail to
+describe the parameters accurately (MS SQL Server sometimes does this
+with some SQL like I<select myfunc(?)  where 1 = 1>). Setting
+C<odbc_force_bind_type> to C<SQL_VARCHAR> will force DBD::ODBC to bind
+all the parameters as C<SQL_VARCHAR> and ignore SQLDescribeParam.
+
+Bare in mind that if you are inserting unicode data you probably want
+to use C<SQL_WVARCHAR> and not C<SQL_VARCHAR>.
+
+As this attribute was created to work around buggy ODBC Drivers which
+support SQLDescribeParam but describe the parameters incorrectly you
+are probably better specifying the bind type on the C<bind_param> call
+on a per statement level rather than blindly setting
+C<odbc_force_bind_type> across a whole connection.
+
+B<N.B> If you call the C<bind_param> method with a SQL type this
+overrides everything else above.
+
 =head3 odbc_force_rebind
 
 This is to handle special cases, especially when using multiple result sets.
@@ -707,7 +757,7 @@ Allow asynchronous execution of queries.  This causes a spin-loop
 (i.e., while the ODBC API returns C<SQL_STILL_EXECUTING>).  This is
 useful, however, if you want the error handling and asynchronous
 messages (see the L</odbc_err_handler> and F<t/20SQLServer.t> for an
-example of this.
+example of this).
 
 =head3 odbc_query_timeout
 
@@ -760,6 +810,19 @@ where the size cannot be determined.
 The default for odbc_column_display_size is 2001 because this value was
 hard-coded in DBD::ODBC until 1.17_3.
 
+=head3 odbc_utf8_on
+
+Set this flag to treat all strings returned from the ODBC driver
+(except columns described as SQL_BINARY or SQL_TIMESTAMP and its
+variations) as UTF-8 encoded.  Some ODBC drivers (like Aster and maybe
+PostgreSQL) return UTF-8 encoded data but do not support the SQLxxxW
+unicode API. Enabling this flag will cause DBD::ODBC to treat driver
+returned data as UTF-8 encoded and it will be marked as such in Perl.
+
+Do not confuse this with DBD::ODBC's unicode support. The
+C<odbc_utf8_on> attribute only applies to non-unicode enabled builds
+of DBD::ODBC.
+
 =head2 Private connection attributes
 
 =head3 odbc_err_handler
@@ -1416,7 +1479,7 @@ wchar_t types (which are usually 4) and hence DBD::ODBC will not work
 iODBC when built for unicode.
 
 The ODBC Driver must expect Unicode data specified in SQLBindParameter
-and SQLBindCol to be UTF16 in local endianess. Similarly, in calls to
+and SQLBindCol to be UTF16 in local endianness. Similarly, in calls to
 SQLPrepareW, SQLDescribeColW and SQLDriverConnectW.
 
 You should be aware that once Unicode support is enabled it affects a
@@ -1481,6 +1544,8 @@ you are better off using L<DBD::Oracle>.
 
 =head3 Unicode and PostgreSQL
 
+See the odbc_utf8_on parameter to treat all strings as utf8.
+
 Some tests from the original DBD::ODBC 1.13 fail with PostgreSQL
 8.0.3, so you may not want to use DBD::ODBC to connect to PostgreSQL
 8.0.3.
@@ -1509,7 +1574,7 @@ let me know and I will include it here.
 =head3 Drivers without SQLDescribeParam
 
 Some drivers do not support the C<SQLDescribeParam> ODBC API (e.g.,
-Microsoft Access).
+Microsoft Access, FreeTDS).
 
 DBD::ODBC uses the C<SQLDescribeParam> API when parameters are bound
 to your SQL to find the types of the parameters. If the ODBC driver
